@@ -1,13 +1,11 @@
-# -*- coding: utf-8 -*-
 from hcloud.actions.client import BoundAction
-from hcloud.core.client import ClientEntityBase, BoundModelBase, GetEntityByNameMixin
-
 from hcloud.certificates.domain import (
     Certificate,
     CreateManagedCertificateResponse,
-    ManagedCertificateStatus,
     ManagedCertificateError,
+    ManagedCertificateStatus,
 )
+from hcloud.core.client import BoundModelBase, ClientEntityBase, GetEntityByNameMixin
 from hcloud.core.domain import add_meta_to_result
 
 
@@ -26,7 +24,7 @@ class BoundCertificate(BoundModelBase):
             data["status"] = ManagedCertificateStatus(
                 issuance=status["issuance"], renewal=status["renewal"], error=error
             )
-        super(BoundCertificate, self).__init__(client, data, complete)
+        super().__init__(client, data, complete)
 
     def get_actions_list(self, status=None, sort=None, page=None, per_page=None):
         # type: (Optional[List[str]], Optional[List[str]], Optional[int], Optional[int]) -> PageResults[List[BoundAction, Meta]]
@@ -93,9 +91,7 @@ class CertificatesClient(ClientEntityBase, GetEntityByNameMixin):
         :param id: int
         :return: :class:`BoundCertificate <hcloud.certificates.client.BoundCertificate>`
         """
-        response = self._client.request(
-            url="/certificates/{certificate_id}".format(certificate_id=id), method="GET"
-        )
+        response = self._client.request(url=f"/certificates/{id}", method="GET")
         return BoundCertificate(self, response["certificate"])
 
     def get_list(
@@ -143,7 +139,7 @@ class CertificatesClient(ClientEntityBase, GetEntityByNameMixin):
         return self._add_meta_to_result(certificates, response)
 
     def get_all(self, name=None, label_selector=None):
-        # type: (Optional[str]) -> List[BoundCertificate]
+        # type: (Optional[str], Optional[str]) -> List[BoundCertificate]
         """Get all certificates
 
         :param name: str (optional)
@@ -152,9 +148,7 @@ class CertificatesClient(ClientEntityBase, GetEntityByNameMixin):
                Can be used to filter certificates by labels. The response will only contain certificates matching the label selector.
         :return: List[:class:`BoundCertificate <hcloud.certificates.client.BoundCertificate>`]
         """
-        return super(CertificatesClient, self).get_all(
-            name=name, label_selector=label_selector
-        )
+        return super().get_all(name=name, label_selector=label_selector)
 
     def get_by_name(self, name):
         # type: (str) -> BoundCertificate
@@ -164,10 +158,10 @@ class CertificatesClient(ClientEntityBase, GetEntityByNameMixin):
                Used to get certificate by name.
         :return: :class:`BoundCertificate <hcloud.certificates.client.BoundCertificate>`
         """
-        return super(CertificatesClient, self).get_by_name(name)
+        return super().get_by_name(name)
 
     def create(self, name, certificate, private_key, labels=None):
-        # type: (str, str, Optional[Dict[str, str]]) -> BoundCertificate
+        # type: (str, str, str, Optional[Dict[str, str]]) -> BoundCertificate
         """Creates a new Certificate with the given name, certificate and private_key. This methods allows only creating
            custom uploaded certificates. If you want to create a managed certificate use :func:`~hcloud.certificates.client.CertificatesClient.create_managed`
 
@@ -233,7 +227,7 @@ class CertificatesClient(ClientEntityBase, GetEntityByNameMixin):
         if labels is not None:
             data["labels"] = labels
         response = self._client.request(
-            url="/certificates/{certificate_id}".format(certificate_id=certificate.id),
+            url=f"/certificates/{certificate.id}",
             method="PUT",
             json=data,
         )
@@ -242,7 +236,7 @@ class CertificatesClient(ClientEntityBase, GetEntityByNameMixin):
     def delete(self, certificate):
         # type: (Certificate) -> bool
         self._client.request(
-            url="/certificates/{certificate_id}".format(certificate_id=certificate.id),
+            url=f"/certificates/{certificate.id}",
             method="DELETE",
         )
         """Deletes a certificate.
@@ -304,9 +298,7 @@ class CertificatesClient(ClientEntityBase, GetEntityByNameMixin):
                Specify how the results are sorted. Choices: `id` `id:asc` `id:desc` `command` `command:asc` `command:desc` `status` `status:asc` `status:desc` `progress` `progress:asc` `progress:desc` `started` `started:asc` `started:desc` `finished` `finished:asc` `finished:desc`
         :return: List[:class:`BoundAction <hcloud.actions.client.BoundAction>`]
         """
-        return super(CertificatesClient, self).get_actions(
-            certificate, status=status, sort=sort
-        )
+        return super().get_actions(certificate, status=status, sort=sort)
 
     def retry_issuance(self, certificate):
         # type: (Certificate) -> BoundAction
