@@ -1,31 +1,27 @@
-# -*- coding: utf-8 -*-
-from hcloud.certificates.client import BoundCertificate
-from hcloud.servers.client import BoundServer
-
-from hcloud.load_balancer_types.client import BoundLoadBalancerType
-from hcloud.locations.client import BoundLocation
-from hcloud.networks.client import BoundNetwork
-
-from hcloud.core.client import ClientEntityBase, BoundModelBase, GetEntityByNameMixin
-from hcloud.core.domain import add_meta_to_result
-
 from hcloud.actions.client import BoundAction
+from hcloud.certificates.client import BoundCertificate
+from hcloud.core.client import BoundModelBase, ClientEntityBase, GetEntityByNameMixin
+from hcloud.core.domain import add_meta_to_result
+from hcloud.load_balancer_types.client import BoundLoadBalancerType
 from hcloud.load_balancers.domain import (
-    LoadBalancer,
+    CreateLoadBalancerResponse,
     IPv4Address,
     IPv6Network,
-    PublicNetwork,
-    PrivateNet,
-    CreateLoadBalancerResponse,
-    LoadBalancerTarget,
+    LoadBalancer,
+    LoadBalancerAlgorithm,
+    LoadBalancerHealtCheckHttp,
+    LoadBalancerHealthCheck,
     LoadBalancerService,
     LoadBalancerServiceHttp,
-    LoadBalancerHealthCheck,
-    LoadBalancerHealtCheckHttp,
-    LoadBalancerAlgorithm,
-    LoadBalancerTargetLabelSelector,
+    LoadBalancerTarget,
     LoadBalancerTargetIP,
+    LoadBalancerTargetLabelSelector,
+    PrivateNet,
+    PublicNetwork,
 )
+from hcloud.locations.client import BoundLocation
+from hcloud.networks.client import BoundNetwork
+from hcloud.servers.client import BoundServer
 
 
 class BoundLoadBalancer(BoundModelBase):
@@ -133,7 +129,7 @@ class BoundLoadBalancer(BoundModelBase):
         if location is not None:
             data["location"] = BoundLocation(client._client.locations, location)
 
-        super(BoundLoadBalancer, self).__init__(client, data, complete)
+        super().__init__(client, data, complete)
 
     def update(self, name=None, labels=None):
         # type: (Optional[str], Optional[Dict[str, str]]) -> BoundLoadBalancer
@@ -323,7 +319,7 @@ class LoadBalancersClient(ClientEntityBase, GetEntityByNameMixin):
         :return: :class:`BoundLoadBalancer <hcloud.load_balancers.client.BoundLoadBalancer>`
         """
         response = self._client.request(
-            url="/load_balancers/{load_balancer_id}".format(load_balancer_id=id),
+            url=f"/load_balancers/{id}",
             method="GET",
         )
         return BoundLoadBalancer(self, response["load_balancer"])
@@ -378,9 +374,7 @@ class LoadBalancersClient(ClientEntityBase, GetEntityByNameMixin):
                Can be used to filter Load Balancers by labels. The response will only contain Load Balancers matching the label selector.
         :return: List[:class:`BoundLoadBalancer <hcloud.load_balancers.client.BoundLoadBalancer>`]
         """
-        return super(LoadBalancersClient, self).get_all(
-            name=name, label_selector=label_selector
-        )
+        return super().get_all(name=name, label_selector=label_selector)
 
     def get_by_name(self, name):
         # type: (str) -> BoundLoadBalancer
@@ -390,7 +384,7 @@ class LoadBalancersClient(ClientEntityBase, GetEntityByNameMixin):
                Used to get Load Balancer by name.
         :return: :class:`BoundLoadBalancer <hcloud.load_balancers.client.BoundLoadBalancer>`
         """
-        return super(LoadBalancersClient, self).get_by_name(name)
+        return super().get_by_name(name)
 
     def create(
         self,
@@ -405,7 +399,7 @@ class LoadBalancersClient(ClientEntityBase, GetEntityByNameMixin):
         public_interface=None,  # type: Optional[bool]
         network=None,  # type: Optional[Union[Network,BoundNetwork]]
     ):
-        # type: (...) -> CreateLoadBalancerResponse:
+        # type: (...) -> CreateLoadBalancerResponse
         """Creates a Load Balancer .
 
         :param name: str
@@ -567,9 +561,7 @@ class LoadBalancersClient(ClientEntityBase, GetEntityByNameMixin):
                Specify how the results are sorted. Choices: `id` `id:asc` `id:desc` `command` `command:asc` `command:desc` `status` `status:asc` `status:desc` `progress` `progress:asc` `progress:desc` `started` `started:asc` `started:desc` `finished` `finished:asc` `finished:desc`
         :return: List[:class:`BoundAction <hcloud.actions.client.BoundAction>`]
         """
-        return super(LoadBalancersClient, self).get_actions(
-            load_balancer, status=status, sort=sort
-        )
+        return super().get_actions(load_balancer, status=status, sort=sort)
 
     def add_service(self, load_balancer, service):
         # type: (Union[LoadBalancer, BoundLoadBalancer], LoadBalancerService) -> List[BoundAction]
